---
title: <span class="badge object-type-scalar"></span> LitrePerHour
---
# <span class="badge object-type-scalar"></span> LitrePerHour

Flow: Litre/hour

## Definition

```python
# Flow: Litre/hour
LitrePerHour: typing.Literal["litreh"] = "litreh"
```
